REST API Automatic Generated Documentation — Rucio 0.3.8 documentation

# REST API Automatic Generated Documentation

WARNING

The following documentation was generated automatically from a script in tools/generateRESTDocs.py.

This script extract useful information directly from source code, but with a best effort approach.

In any case, this documentation can be helpful, but in some cases will be PLAIN WRONG.

In some cases the URLs reported are incomplete, the raised exceptions will contain strange strings and in all the cases the correct return value (which usually is 200 OK or 203 CREATED) in case of no error is omitted.

The documentation is organized by source code, so REST_account.html will contain the documentation for the rucio/web/rest/acccount.py source file.

If you found an inconsistency with the behavior of Rucio REST API and this documentation, please don’t hesitate in submit a JIRA ticket.

## Automatic Generated Docs

- account.py
- authentication.py
- did.py
- identity.py
- lock.py
- meta.py
- redirect.py
- replica.py
- rse.py
- rule.py
- scope.py
- subscription.py